import React__default,{useState,useEffect}from'react';import {useDispatch,useSelector}from'react-redux';import {FieldTimeOutlined}from'@ant-design/icons';import Draggable from'react-draggable';import {Button,message}from'antd';import {useFela}from'react-fela';import {merge,omit}from'lodash';import moment from'moment';import {styleSheet}from'./style.js';import TimerWidget from'./TimerWidget/index.js';import {currentTimerSelector,setCurrentTimerAction}from'@admin-layout/timetracker-core';import {useGetPlayingTimeRecordQuery,useCreateTimeRecordMutation,useUpdateTimeRecordMutation,SubscribeToTimeTrackerDocument}from'@admin-layout/timetracker-core/lib/generated/react-hooks';import {useCreatePermissions}from'../../hooks/index.js';import {TimerComponent}from'../TimeTracker/TimerComponent.js';import {useInjection}from'@workbench-stack/components';import {generateContributionId,CONTRIBUTION_ACTION_TYPES}from'@adminide-stack/extension-api';const SetCurrentTimer = () => {
    const activityService = useInjection("ActivtyService" /* ActivtyService */);
    const [registerTimeout, setRegisterTimeout] = useState(false);
    const currentTimer = useSelector(currentTimerSelector);
    const dispatch = useDispatch();
    useEffect(() => {
        console.log('---TIMER-----', currentTimer);
        if (currentTimer.startTime !== null && registerTimeout === false) {
            activityService.onTimeoutKeyup((value) => {
                console.log('---TIMER2-----', currentTimer);
                if (currentTimer.startTime !== null) {
                    dispatch(setCurrentTimerAction(Object.assign(Object.assign({}, currentTimer), { isTimeout: value, isPause: value })));
                    setRegisterTimeout(true);
                }
            });
            // return activityService.dispose;
        }
    }, [registerTimeout, currentTimer.startTime]);
    return null;
};
const HeaderTimerHandler = (props) => {
    const { css } = useFela();
    const [visiblity, setVisiblity] = useState(false);
    const dispatch = useDispatch();
    const [startTimer, setStartTimer] = useState(false);
    const [isPause, setIsPause] = useState(false);
    const [currentTimeRecord, setCurrentTimeRecord] = useState({
        startTime: null,
        endTime: null,
        isBillable: false,
        description: '',
        projectId: '',
        taskName: '',
    });
    const userId = useSelector((state) => state.user.auth0UserId);
    const orgName = useSelector((state) => state.platform.orgName);
    const currentTimer = useSelector(currentTimerSelector);
    const { data: plData, loading: plLoading, subscribeToMore } = useGetPlayingTimeRecordQuery();
    const [createMutation] = useCreateTimeRecordMutation();
    const [updateMutation] = useUpdateTimeRecordMutation();
    const { self: createPermit } = useCreatePermissions();
    useEffect(() => {
        const id = generateContributionId();
        const contribution = {
            [id]: {
                pageNavBar: [
                    { name: 'dispatch-action', position: 'right', component: () => React__default.createElement(SetCurrentTimer, null) },
                ],
            },
        };
        // register contribution
        dispatch({
            type: CONTRIBUTION_ACTION_TYPES.REGISTER_CONTRIBUTIONS,
            payload: contribution,
        });
        return () => {
            dispatch({
                type: CONTRIBUTION_ACTION_TYPES.DEREGISTER_CONTRIBUTIONS,
                payload: contribution,
            });
        };
    }, []);
    useEffect(() => {
        if (currentTimer.isPause !== isPause) {
            setIsPause(currentTimer.isPause);
        }
    }, [currentTimer]);
    const hidePopover = () => {
        setVisiblity(false);
    };
    useEffect(() => {
        const unsubscribe = subscribeToMore(getSubscriptionOptions({ userId, orgName }));
        return () => unsubscribe();
    }, [orgName, userId, subscribeToMore]);
    useEffect(() => {
        if (plData && plData.getPlayingTimeRecord && plData.getPlayingTimeRecord.startTime) {
            const playingRecord = plData.getPlayingTimeRecord;
            setCurrentTimeRecord(playingRecord);
            dispatch(setCurrentTimerAction(Object.assign(Object.assign({}, playingRecord), { isPause })));
            setStartTimer(true);
        }
        else if (startTimer) {
            resetTimerValues();
        }
    }, [plData, plLoading]);
    const getSubscriptionOptions = ({ userId, orgName, }) => {
        return {
            document: SubscribeToTimeTrackerDocument,
            variables: { userId, orgName },
            updateQuery: (prev, { subscriptionData }) => {
                var _a, _b;
                if (!subscriptionData.data.SubscribeToTimeTracker) {
                    return prev;
                }
                const subscribedData = subscriptionData.data.SubscribeToTimeTracker;
                if ((subscribedData.mutation === "TimeRecordCreated" /* TimeRecordCreated */ ||
                    subscribedData.mutation === "TimeRecordUpdated" /* TimeRecordUpdated */) &&
                    ((_a = subscribedData.timeRecord) === null || _a === void 0 ? void 0 : _a.endTime) === null) {
                    const newData = merge({}, prev, {
                        getPlayingTimeRecord: subscriptionData.data.SubscribeToTimeTracker.timeRecord,
                    });
                    return newData;
                }
                else if (subscribedData.mutation === "TimeRecordUpdated" /* TimeRecordUpdated */ &&
                    ((_b = subscribedData.timeRecord) === null || _b === void 0 ? void 0 : _b.endTime) !== null) {
                    return {
                        getPlayingTimeRecord: {
                            __typename: 'TimeRecord',
                            id: '',
                            description: '',
                            endTime: '',
                            isBillable: false,
                            projectId: '',
                            taskName: '',
                            tags: [],
                            startTime: '',
                            userId: '',
                        },
                    };
                }
            },
        };
    };
    // create time record
    const createTimeRecord = (request) => {
        if (createPermit !== "Allow" /* Allow */) {
            message.warning('Permission Not Allowed');
            return;
        }
        createMutation({ variables: { request } })
            .then(() => {
            message.info('TimeRecord created');
        })
            .catch((error) => {
            message.error(error.message);
        });
    };
    // update time record
    const updateTimeRecord = (recordId, request) => {
        updateMutation({ variables: { recordId, request } })
            .then(() => {
            message.success('TimeRecord Updated');
        })
            .catch((error) => {
            message.error(error.message);
        });
    };
    const resetTimerValues = () => {
        setStartTimer(false);
        const defaultPlayingRecord = {
            startTime: null,
            description: '',
            endTime: null,
            isBillable: false,
            projectId: '',
            taskName: '',
        };
        setCurrentTimeRecord(Object.assign({}, defaultPlayingRecord));
        dispatch(setCurrentTimerAction(Object.assign(Object.assign({}, defaultPlayingRecord), { isPause: false, isTimeout: false })));
    };
    // save current time record to database
    const saveCurrentTimeRecord = () => {
        const endTime = moment();
        const startTime = moment(currentTimeRecord.startTime);
        const newTimeRecord = {
            userId: userId,
            startTime: startTime,
            endTime: endTime,
            description: currentTimeRecord.description,
            projectId: currentTimeRecord.projectId,
            isBillable: currentTimeRecord.isBillable,
            taskName: currentTimeRecord.taskName,
        };
        if (currentTimeRecord.id === undefined || currentTimeRecord.id === '')
            createTimeRecord(newTimeRecord);
        else
            updateTimeRecord(currentTimeRecord.id, newTimeRecord);
    };
    const updatePlayingTimeRecord = (timeRecord) => {
        setCurrentTimeRecord(timeRecord);
        if (currentTimeRecord.id !== undefined && currentTimeRecord.id !== '') {
            updateTimeRecord(timeRecord.id, Object.assign({}, omit(timeRecord, ['__typename', 'id'])));
        }
    };
    const onStartTimer = () => {
        if (currentTimeRecord.startTime === null) {
            const newTimeRecord = Object.assign(Object.assign({}, currentTimeRecord), { userId, startTime: moment(), endTime: null });
            createTimeRecord(newTimeRecord);
        }
        else {
            dispatch(setCurrentTimerAction(Object.assign(Object.assign({}, currentTimer), { isPause: false })));
        }
    };
    const onStopTimer = () => {
        saveCurrentTimeRecord();
    };
    const onPauseTimer = () => {
        dispatch(setCurrentTimerAction(Object.assign(Object.assign({}, currentTimer), { isPause: true })));
    };
    return (React__default.createElement(React__default.Fragment, null,
        React__default.createElement(Draggable, { handle: "._handler", defaultPosition: { x: 0, y: 60 }, position: null, grid: [25, 25], scale: 1, bounds: ".ant-layout:not(.ant-layout-has-sider)" },
            React__default.createElement("div", { hidden: !visiblity, className: '_handler', style: { zIndex: 999, position: 'absolute' } },
                React__default.createElement(TimerWidget, { onClose: hidePopover, onStart: onStartTimer, onPause: onPauseTimer, onStop: onStopTimer, isPause: isPause, trackStarted: startTimer, currentTimeRecord: currentTimeRecord, updatePlayingTimeRecord: updatePlayingTimeRecord }))),
        React__default.createElement(Button, { className: css(styleSheet.button), type: startTimer ? 'primary' : 'default', icon: React__default.createElement(FieldTimeOutlined, { className: css(styleSheet.icon) }), onClick: () => setVisiblity(!visiblity) },
            React__default.createElement(TimerComponent, null))));
};export default HeaderTimerHandler;//# sourceMappingURL=index.js.map
