import React__default,{useState,useMemo,useCallback}from'react';import classNames from'classnames';import moment from'moment';import {useFela}from'react-fela';import {Menu,Row,Col,Input,Dropdown,Button,Typography}from'antd';import {DeleteOutlined,PlusCircleOutlined,BarsOutlined,TagOutlined,CaretRightOutlined,MoreOutlined}from'@ant-design/icons';import*as _ from'lodash';import {formatDuration}from'../../services/timeRecordService.js';import BillableCheck from'../BillableCheck/index.js';import {useTimeformat}from'../../hooks/index.js';const { Title } = Typography;
const calcTotalTime = (startTime, endTime) => {
    return Math.floor((moment(endTime).valueOf() - moment(startTime).valueOf()) / 1000);
};
const TimerActivityItem = (props) => {
    var _a, _b, _c, _d;
    const { removeTimeRecord, timeRecord, disablePlay, disableDelete, updateTimeRecord, handlePlayTimer } = props;
    const { css } = useFela(props);
    const [selectedProject, setSelectedProject] = useState((_a = timeRecord.projectId) !== null && _a !== void 0 ? _a : '');
    const [taskName, setTaskName] = useState((_b = timeRecord.taskName) !== null && _b !== void 0 ? _b : '');
    const [description, setDescription] = useState((_c = timeRecord.description) !== null && _c !== void 0 ? _c : '');
    const [isBillable, setIsBillable] = useState(timeRecord.isBillable);
    const { timeFormat } = useTimeformat();
    const { projects } = props;
    const debounceTimeLimit = 800;
    const handleSelectProject = (projectId) => {
        const request = Object.assign(Object.assign({}, _.omit(timeRecord, ['__typename', 'id'])), { projectId });
        updateTimeRecord(timeRecord.id, request);
        setSelectedProject(projectId);
    };
    const handleRemove = () => {
        removeTimeRecord(timeRecord.id);
    };
    const menus = (React__default.createElement(Menu, null,
        React__default.createElement(Menu.Item, { key: "remove", icon: React__default.createElement(DeleteOutlined, null), onClick: handleRemove, disabled: disableDelete }, "Remove")));
    const projectDropdownMenus = (React__default.createElement(Menu, { className: css(styles.projectDown) }, projects.map((project) => {
        return (React__default.createElement(Menu.Item, { key: project.id, className: classNames({ selected: selectedProject === project.id }), onClick: () => handleSelectProject(project.id) }, project.name));
    })));
    const debouncedFunc = useMemo(() => _.debounce((value) => {
        const request = Object.assign(Object.assign({}, _.omit(timeRecord, ['__typename', 'id'])), { description: value, taskName: value });
        updateTimeRecord(timeRecord.id, request);
    }, debounceTimeLimit), []);
    useCallback((e) => {
        e.persist();
        setTaskName(e.target.value);
        debouncedFunc(e.target.value);
    }, [debouncedFunc]);
    const handleDescriptionTask = useCallback((e) => {
        e.persist();
        setDescription(e.target.value);
        debouncedFunc(e.target.value);
    }, [debouncedFunc]);
    const handleChangeBillable = () => {
        setIsBillable(!isBillable);
        updateTimeRecord(timeRecord.id, Object.assign(Object.assign({}, _.omit(timeRecord, ['__typename', 'id'])), { isBillable: !timeRecord.isBillable }));
    };
    return (React__default.createElement("div", { className: css(styles.timeRecord) },
        React__default.createElement(Row, { style: { backgroundColor: timeRecord.timesheetId ? '#f0f0f0' : 'white' } },
            React__default.createElement(Col, { span: 24, xl: 12, className: "input" },
                React__default.createElement(Row, { style: { width: '100%' } },
                    React__default.createElement(Col, { span: 18 },
                        React__default.createElement(Input, { placeholder: !timeRecord.timesheetId ? 'What are you working on?' : '', size: "large", value: description, onChange: handleDescriptionTask, disabled: !!timeRecord.timesheetId })),
                    React__default.createElement(Col, { span: 6, className: "flex-end project-selection" },
                        React__default.createElement(Dropdown, { overlay: projectDropdownMenus, trigger: ['click'], disabled: !!timeRecord.timesheetId },
                            React__default.createElement(Button, { icon: selectedProject === '' ? React__default.createElement(PlusCircleOutlined, null) : React__default.createElement(BarsOutlined, null), style: selectedProject === '' ? { textAlign: 'left' } : { textAlign: 'left', color: 'green' }, type: "text", disabled: !!timeRecord.timesheetId }, selectedProject === '' ? 'Projects' : (_d = projects.find((p) => p.id === selectedProject)) === null || _d === void 0 ? void 0 : _d.name))))),
            React__default.createElement(Col, { span: 24, xl: 12, className: "control" },
                React__default.createElement(Row, { style: { width: '100%' } },
                    React__default.createElement(Col, { span: 2, className: "flex-center" },
                        React__default.createElement(Button, { icon: React__default.createElement(TagOutlined, null), type: "text", size: "large" })),
                    React__default.createElement(Col, { span: 2, className: "flex-center" },
                        React__default.createElement(BillableCheck, { checked: isBillable, onChange: handleChangeBillable, disabled: !!timeRecord.timesheetId })),
                    React__default.createElement(Col, { span: 14, sm: 6, className: "flex-center" },
                        React__default.createElement(Title, { level: 5 },
                            moment(timeRecord.startTime).format(timeFormat),
                            " \u00A0- \u00A0",
                            moment(timeRecord.endTime).format(timeFormat))),
                    React__default.createElement(Col, { span: 6, className: "duration" },
                        React__default.createElement(Title, { level: 5 }, formatDuration(calcTotalTime(timeRecord.startTime, timeRecord.endTime)))),
                    React__default.createElement(Col, { span: 4, className: "flex-end" },
                        React__default.createElement(Button, { type: "primary", size: "large", icon: React__default.createElement(CaretRightOutlined, null), onClick: () => handlePlayTimer(timeRecord), disabled: disablePlay }),
                        React__default.createElement(Dropdown, { overlay: menus, trigger: ['click'], disabled: !!timeRecord.timesheetId },
                            React__default.createElement(Button, { icon: React__default.createElement(MoreOutlined, null), size: "large" }))))))));
};
const styles = {
    timeRecord: (theme) => ({
        padding: '5px 10px',
        border: '1px solid #eee',
        borderRadius: '5px',
        backgroundColor: 'white',
        '& .project-selection': {
            overflow: 'hidden',
        },
        '& .input': {
            display: 'flex',
            flexDirection: 'row',
            justifyContent: 'space-between',
            alignItems: 'center',
        },
        '& .control': {
            display: 'flex',
            flexDirection: 'row',
            justifyContent: 'flex-end',
            '@media (max-width: 1200px)': {
                justifyContent: 'space-between',
                marginTop: '10px',
                borderTop: '1px solid #eee',
            },
            '@media (max-width: 768px)': {
                flexDirection: 'column',
                justifyContent: 'space-between',
            },
            alignItems: 'center',
            '& > div': {
                padding: '5px 5px',
                display: 'flex',
                flexDirection: 'row',
                justifyContent: 'space-between',
                '@media (max-width: 768px)': {
                    width: '100%',
                    justifyContent: 'space-around',
                },
            },
            '& .divider': {
                borderLeft: '1px dashed #eee',
                height: '75%',
            },
            '& .hidden': {
                display: 'none',
            },
            '& .total-time': {
                width: '100px',
            },
            '& .more': {
                padding: '0px',
                marginRight: '-10px',
                marginLeft: '-10px',
            },
            '& .duration': {
                display: 'flex',
                alignItems: 'center',
                justifyContent: 'center',
                '@media(max-width: 576px)': {
                    display: 'none',
                },
            },
        },
        '& .flex-center': {
            display: 'flex',
            alignItems: 'center',
            justifyContent: 'center',
        },
        '& .flex-end': {
            display: 'flex',
            alignItems: 'center',
            justifyContent: 'flex-end',
        },
        '& h5': {
            marginBottom: '0px',
            textAlign: 'center',
        },
    }),
    projectDown: ({ theme }) => ({
        display: 'block',
        '& .selected': {
            fontStyle: 'bold',
            color: 'red',
        },
    }),
};export{TimerActivityItem};//# sourceMappingURL=index.js.map
